@@ -1,13 +1,12 @@
 package org.jmx4perl.client.request;
 
-import org.jmx4perl.AgentServlet;
+import org.jmx4perl.http.AgentServlet;
 import org.jmx4perl.client.J4pClient;
 import org.jmx4perl.it.ItSetup;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
 import org.mortbay.jetty.Server;
 import org.mortbay.jetty.servlet.Context;
 import org.mortbay.jetty.servlet.ServletHolder;
+import org.testng.annotations.*;
 
 /**
  * @author roland
@@ -15,9 +14,9 @@ import org.mortbay.jetty.servlet.ServletHolder;
  */
 abstract public class AbstractJ4pIntegrationTest {
 
-    private static Server jettyServer;
+    private Server jettyServer;
 
-    protected static ItSetup itSetup;
+    protected ItSetup itSetup;
 
     private static final int JETTY_DEFAULT_PORT = 8234;
     private static final String SERVER_BASE_URL = "http://localhost:" + JETTY_DEFAULT_PORT;
@@ -25,17 +24,13 @@ abstract public class AbstractJ4pIntegrationTest {
 
     protected static final String J4P_DEFAULT_URL = SERVER_BASE_URL + J4P_CONTEXT;
 
-    static String j4pUrl;
+    private String j4pUrl;
 
     // Client which can be used by subclasses for testing
     protected J4pClient j4pClient;
 
-    public AbstractJ4pIntegrationTest() {
-        j4pClient = new J4pClient(j4pUrl);
-    }
-
     @BeforeClass
-	public static void start() throws Exception {
+    public void start() throws Exception {
         String testUrl = System.getProperty("j4p.url");
         itSetup = new ItSetup();
         if (testUrl == null) {
@@ -49,10 +44,11 @@ abstract public class AbstractJ4pIntegrationTest {
         } else {
             j4pUrl = testUrl;
         }
+        j4pClient = new J4pClient(j4pUrl);
 	}
 
     @AfterClass
-	public static void stop() throws Exception {
+	public void stop() throws Exception {
 		if (jettyServer != null) {
 			jettyServer.stop();
 		}
