@@ -1,15 +1,12 @@
 package org.jmx4perl.client.request;
 
-import java.io.IOException;
-
 import org.apache.http.client.methods.HttpPost;
 import org.jmx4perl.Version;
-import org.jmx4perl.client.J4pException;
-import org.jmx4perl.client.response.J4pVersionResponse;
-import org.json.simple.parser.ParseException;
-import org.junit.Test;
+import org.jmx4perl.client.exception.J4pException;
+import org.testng.annotations.Test;
 
-import static org.junit.Assert.*;
+import static org.testng.AssertJUnit.assertEquals;
+import static org.testng.AssertJUnit.assertTrue;
 
 /**
  * @author roland
