@@ -1,9 +1,8 @@
 package org.jmx4perl.it;
 
-import javax.management.MBeanRegistration;
-import javax.management.ObjectName;
-import javax.management.MBeanServer;
-import javax.management.MalformedObjectNameException;
+import java.util.List;
+
+import javax.management.*;
 
 /**
  * @author roland
@@ -33,6 +32,10 @@ public class OperationChecking implements OperationCheckingMBean,MBeanRegistrati
         return arg1 != null && arg1.length() == 0;
     }
 
+    public String arrayArguments(String args[], String extra) {
+        return args[0];
+    }
+
     public int overloadedMethod(String arg) {
         return 1;
     }
