@@ -39,6 +39,20 @@ import java.util.*;
  * @since Jun 12, 2009
  */
 public class ListHandler extends JsonRequestHandler {
+
+    // Properties for JSON answer
+    private static final String KEY_DESCRIPTION = "desc";
+    private static final String KEY_ERROR = "error";
+    private static final String KEY_NAME = "name";
+    private static final String KEY_TYPES = "types";
+    private static final String KEY_ARGS = "args";
+    private static final String KEY_RETURN = "ret";
+    private static final String KEY_OPERATION = "op";
+    private static final String KEY_TYPE = "type";
+    private static final String KEY_NOTIFICATION = "not";
+    private static final String KEY_READ_WRITE = "rw";
+    private static final String KEY_ATTRIBUTE = "attr";
+
     public JmxRequest.Type getType() {
         return JmxRequest.Type.LIST;
     }
@@ -69,7 +83,7 @@ public class ListHandler extends JsonRequestHandler {
 
                     try {
                         MBeanInfo mBeanInfo = server.getMBeanInfo(name);
-                        mBeanMap.put("desc",mBeanInfo.getDescription());
+                        mBeanMap.put(KEY_DESCRIPTION,mBeanInfo.getDescription());
                         addAttributes(mBeanMap, mBeanInfo);
                         addOperations(mBeanMap, mBeanInfo);
                         addNotifications(mBeanMap, mBeanInfo);
@@ -83,7 +97,7 @@ public class ListHandler extends JsonRequestHandler {
                     } catch (IOException exp) {
                         // In case of a remote call, IOEcxeption can occur e.g. for
                         // NonSerializableExceptions
-                        mBeanMap.put("error",exp);
+                        mBeanMap.put(KEY_ERROR,exp);
                     }
                 }
             }
@@ -100,12 +114,12 @@ public class ListHandler extends JsonRequestHandler {
         Map notMap = new HashMap();
         for (MBeanNotificationInfo notInfo : pMBeanInfo.getNotifications()) {
             Map map = new HashMap();
-            map.put("name",notInfo.getName());
-            map.put("desc",notInfo.getDescription());
-            map.put("types",notInfo.getNotifTypes());
+            map.put(KEY_NAME,notInfo.getName());
+            map.put(KEY_DESCRIPTION,notInfo.getDescription());
+            map.put(KEY_TYPES,notInfo.getNotifTypes());
         }
         if (notMap.size() > 0) {
-            pMBeanMap.put("not",notMap);
+            pMBeanMap.put(KEY_NOTIFICATION,notMap);
         }
     }
 
@@ -117,14 +131,14 @@ public class ListHandler extends JsonRequestHandler {
             List argList = new ArrayList();
             for (MBeanParameterInfo paramInfo :  opInfo.getSignature()) {
                 Map args = new HashMap();
-                args.put("desc",paramInfo.getDescription());
-                args.put("name",paramInfo.getName());
-                args.put("type",paramInfo.getType());
+                args.put(KEY_DESCRIPTION,paramInfo.getDescription());
+                args.put(KEY_NAME,paramInfo.getName());
+                args.put(KEY_TYPE,paramInfo.getType());
                 argList.add(args);
             }
-            map.put("args",argList);
-            map.put("ret",opInfo.getReturnType());
-            map.put("desc",opInfo.getDescription());
+            map.put(KEY_ARGS,argList);
+            map.put(KEY_RETURN,opInfo.getReturnType());
+            map.put(KEY_DESCRIPTION,opInfo.getDescription());
             Object ops = opMap.get(opInfo.getName());
             if (ops != null) {
                 if (ops instanceof List) {
@@ -147,7 +161,7 @@ public class ListHandler extends JsonRequestHandler {
             }
         }
         if (opMap.size() > 0) {
-            pMBeanMap.put("op",opMap);
+            pMBeanMap.put(KEY_OPERATION,opMap);
         }
     }
 
@@ -156,13 +170,13 @@ public class ListHandler extends JsonRequestHandler {
         Map attrMap = new HashMap();
         for (MBeanAttributeInfo attrInfo : pMBeanInfo.getAttributes()) {
             Map map = new HashMap();
-            map.put("type",attrInfo.getType());
-            map.put("desc",attrInfo.getDescription());
-            map.put("rw",Boolean.valueOf(attrInfo.isWritable() && attrInfo.isReadable()));
+            map.put(KEY_TYPE,attrInfo.getType());
+            map.put(KEY_DESCRIPTION,attrInfo.getDescription());
+            map.put(KEY_READ_WRITE,Boolean.valueOf(attrInfo.isWritable() && attrInfo.isReadable()));
             attrMap.put(attrInfo.getName(),map);
         }
         if (attrMap.size() > 0) {
-            pMBeanMap.put("attr",attrMap);
+            pMBeanMap.put(KEY_ATTRIBUTE,attrMap);
         }
     }
 
