@@ -1,10 +1,8 @@
 package ProductTest::Test1Handler;
 
-use JMX::Jmx4Perl::Product::BaseHandler;
+use base qw(JMX::Jmx4Perl::Product::BaseHandler);
 use JMX::Jmx4Perl::Alias;
 
-use vars qw(@ISA);
-@ISA = qw(JMX::Jmx4Perl::Product::BaseHandler);
 
 sub id { return "Test1" };
 
